#
# PySNMP MIB module PKTC-IETF-MTA-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///home/tt/fixed_mibs/PKTC-IETF-MTA-MIB
# Produced by pysmi-0.0.2 at Mon Jun 22 22:27:31 2015
# On host cray platform Linux version 2.6.37.6-smp by user tt
# Using Python version 2.7.2 (default, Apr  2 2012, 20:32:47) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( docsBpi2CodeDownloadGroup, ) = mibBuilder.importSymbols("DOCS-BPI2-MIB", "docsBpi2CodeDownloadGroup")
( docsDevSoftwareGroupV2, ) = mibBuilder.importSymbols("DOCS-CABLE-DEVICE-MIB", "docsDevSoftwareGroupV2")
( DocsX509ASN1DEREncodedCertificate, ) = mibBuilder.importSymbols("DOCS-IETF-BPI2-MIB", "DocsX509ASN1DEREncodedCertificate")
( ifPhysAddress, ) = mibBuilder.importSymbols("IF-MIB", "ifPhysAddress")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( sysDescr, ) = mibBuilder.importSymbols("SNMPv2-MIB", "sysDescr")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, mib_2, TimeTicks, Counter64, Unsigned32, NotificationType, ModuleIdentity, Gauge32, iso, ObjectIdentity, Bits, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "MibIdentifier", "mib-2", "TimeTicks", "Counter64", "Unsigned32", "NotificationType", "ModuleIdentity", "Gauge32", "iso", "ObjectIdentity", "Bits", "Counter32")
( TruthValue, RowStatus, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "RowStatus", "TextualConvention")
( LongUtf8String, ) = mibBuilder.importSymbols("SYSAPPL-MIB", "LongUtf8String")
pktcIetfMtaMib = ModuleIdentity((1, 3, 6, 1, 2, 1, 140)).setRevisions(("2006-09-18 00:00",))
if mibBuilder.loadTexts: pktcIetfMtaMib.setOrganization('IETF IP over Cable Data Network Working Group')
if mibBuilder.loadTexts: pktcIetfMtaMib.setContactInfo('Eugene Nechamkin\n         Broadcom Corporation,\n         200-13711 International Place,\n\n\n\n         Richmond, BC, V6V 2Z8\n         CANADA\n         Phone: +1 604 233 8500\n         Email: enechamkin@broadcom.com\n\n         Jean-Francois Mule\n         Cable Television Laboratories, Inc.\n         858 Coal Creek Circle\n         Louisville, CO 80027-9750\n         U.S.A.\n         Phone: +1 303 661 9100\n         Email: jf.mule@cablelabs.com\n\n    IETF IPCDN Working Group\n         General Discussion: ipcdn@ietf.org\n         Subscribe: http://www.ietf.org/mailman/listinfo/ipcdn\n         Archive: ftp://ftp.ietf.org/ietf-mail-archive/ipcdn\n         Co-Chair: Jean-Francois Mule, jf.mule@cablelabs.com\n         Co-Chair: Richard Woundy, Richard_Woundy@cable.comcast.com')
if mibBuilder.loadTexts: pktcIetfMtaMib.setDescription('This MIB module defines the basic management object\n        for the Multimedia Terminal Adapter devices compliant\n        with PacketCable and IPCablecom requirements.\n\n        Copyright (C) The IETF Trust (2006).  This version of\n        this MIB module is part of RFC 4682; see the RFC itself for\n        full legal notices.')
class PktcMtaDevProvEncryptAlg(TextualConvention, Integer32):
    subtypeSpec = Integer32.subtypeSpec+SingleValueConstraint(0, 1, 2, 3, 4,)
    namedValues = NamedValues(("none", 0), ("des64CbcMode", 1), ("t3Des192CbcMode", 2), ("aes128CbcMode", 3), ("aes256CbcMode", 4),)

pktcMtaNotification = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 0))
pktcMtaMibObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 1))
pktcMtaDevBase = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 1, 1))
pktcMtaDevServer = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 1, 2))
pktcMtaDevSecurity = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 1, 3))
pktcMtaDevErrors = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 1, 4))
pktcMtaConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 2))
pktcMtaDevResetNow = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 1), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevResetNow.setDescription(" This object controls the MTA software reset.\n          Reading this object always returns 'false'.  Setting this\n          object to 'true' causes the device to reset immediately\n          and the following actions to occur:\n             1.  All connections (if present) are flushed locally.\n             2.  All current actions such as ringing immediately\n                 terminate.\n             3.  Requests for signaling notifications, such as\n                 notification based on digit map recognition, are\n                 flushed.\n             4.  All endpoints are disabled.\n             5.  The provisioning flow is started at step MTA-1.\n          If a value is written into an instance of\n          pktcMtaDevResetNow, the agent MUST NOT retain the supplied\n          value across MTA re-initializations or reboots.")
pktcMtaDevSerialNumber = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevSerialNumber.setDescription(" This object specifies the manufacturer's serial\n          number of this MTA.  The value of this object MUST be\n          identical to the value specified in DHCP option 43,\n          sub-option 4.  The list of sub-options for DHCP option\n          43 are defined in the PacketCable MTA Device\n          Provisioning Specification.")
pktcMtaDevSwCurrentVers = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevSwCurrentVers.setDescription(" This object identifies the software version currently\n          operating in the MTA.\n          The MTA MUST return a string descriptive of the current\n          software load.  This object should use the syntax\n          defined by the individual vendor to identify the software\n          version.  The data presented in this object MUST be\n          identical to the software version information contained\n          in the 'sysDescr' MIB object of the MTA.  The value of\n          this object MUST be identical to the value specified in\n          DHCP option 43, sub-option 6.  The list of sub-options for\n          DHCP option 43 are defined in the PacketCable MTA Device\n          Provisioning Specification.")
pktcMtaDevFQDN = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 4), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevFQDN.setDescription(' This object contains the Fully Qualified Domain Name for\n          this MTA.  The MTA FQDN is used to uniquely identify the\n          device to the PacketCable back office elements.')
pktcMtaDevEndPntCount = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevEndPntCount.setDescription(' This object contains the number of physical endpoints for\n          this MTA.')
pktcMtaDevEnabled = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 6), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevEnabled.setDescription(" This object contains the MTA Admin Status of this device.\n           If this object is set to 'true', the MTA is\n           administratively enabled, and the MTA MUST be able to\n           interact with the PacketCable entities, such as CMS,\n           Provisioning Server, KDC, and other MTAs and MGs on all\n           PacketCable interfaces.\n           If this object is set to 'false', the MTA is\n           administratively disabled, and the MTA MUST perform the\n           following actions for all endpoints:\n               - Shut down all media sessions, if present.\n               - Shut down Network Control Signaling (NCS)\n               signaling by following the Restart in\n               Progress procedures in the PacketCable NCS\n               specification.\n           The MTA must execute all actions required to\n           enable or disable the telephony services for all\n           endpoints immediately upon receipt of an SNMP SET\n           operation.\n\n           Additionally, the MTA MUST maintain the SNMP Interface\n           for management and also the SNMP Key management interface.\n           Also, the MTA MUST NOT continue Kerberized key management\n           with CMSes until this object is set to 'true'.\n           Note: MTAs MUST renew the CMS Kerberos tickets according\n           to the PacketCable Security or IPCablecom Specification.\n           If a value is written into an instance of\n           pktcMtaDevEnabled, the agent MUST NOT retain the supplied\n           value across MTA re-initializations or reboots.")
pktcMtaDevTypeIdentifier = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 7), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevTypeIdentifier.setDescription(' This object provides the MTA device type identifier.  The\n          value of this object must be a copy of the DHCP option 60\n          value exchanged between the MTA and the DHCP server.  The\n          DHCP option 60 value contains an ASCII-encoded string\n          identifying capabilities of the MTA as defined in the\n          PacketCable MTA Device Provisioning Specification.')
pktcMtaDevProvisioningState = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 8), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,)).clone(namedValues=NamedValues(("pass", 1), ("inProgress", 2), ("failConfigFileError", 3), ("passWithWarnings", 4), ("passWithIncompleteParsing", 5), ("failureInternalError", 6), ("failureOtherReason", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvisioningState.setDescription(" This object indicates the completion state of the MTA\n          device provisioning process.\n\n          pass:\n          If the configuration file could be parsed successfully\n          and the MTA is able to reflect the same in its\n          MIB, the MTA MUST return the value 'pass'.\n\n          inProgress:\n          If the MTA is in the process of being provisioned,\n          the MTA MUST return the value 'inProgress'.\n\n          failConfigFileError:\n          If the configuration file was in error due to incorrect\n          values in the mandatory parameters, the MTA MUST reject\n          the configuration file, and the MTA MUST return the value\n\n\n\n          'failConfigFileError'.\n\n          passWithWarnings:\n          If the configuration file had proper values for all the\n          mandatory parameters but has errors in any of the optional\n          parameters (this includes any vendor-specific Object\n          Identifiers (OIDs) that are incorrect or not known\n          to the MTA), the MTA MUST return the value\n          'passWithWarnings'.\n\n          passWithIncompleteParsing:\n          If the configuration file is valid but the MTA cannot\n          reflect the same in its configuration (for example, too\n          many entries caused memory exhaustion), it must accept\n          the CMS configuration entries related, and the MTA MUST\n          return the value 'passWithIncompleteParsing'.\n\n          failureInternalError:\n          If the configuration file cannot be parsed due to an\n          Internal error, the MTA MUST return the value\n          'failureInternalError'.\n\n          failureOtherReason:\n          If the MTA cannot accept the configuration file for any\n          other reason than the ones stated above, the MTA MUST\n          return the value 'failureOtherReason'.\n\n          When a final SNMP INFORM is sent as part of Step 25 of the\n          MTA Provisioning process, this parameter is also included\n          in the final INFORM message.")
pktcMtaDevHttpAccess = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 9), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevHttpAccess.setDescription(' This object indicates whether the HTTP protocol is\n          supported for the MTA configuration file transfer.')
pktcMtaDevProvisioningTimer = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 10), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,30)).clone(10)).setUnits('minutes').setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevProvisioningTimer.setDescription(' This object defines the time interval for the provisioning\n          flow to complete.  The MTA MUST finish all provisioning\n          operations starting from the moment when an MTA receives\n          its DHCP ACK and ending at the moment when the MTA\n          downloads its configuration file (e.g., MTA5 to MTA23)\n          within the period of time set by this object.\n          Failure to comply with this condition constitutes\n          a provisioning flow failure.  If the object is set to 0,\n          the MTA MUST ignore the provisioning timer condition.\n          If a value is written into an instance of\n          pktcMtaDevProvisioningTimer, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.')
pktcMtaDevProvisioningCounter = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvisioningCounter.setDescription('This object counts the number of times the\n            provisioning cycle has looped through step MTA-1.')
pktcMtaDevErrorOidsTable = MibTable((1, 3, 6, 1, 2, 1, 140, 1, 1, 12), )
if mibBuilder.loadTexts: pktcMtaDevErrorOidsTable.setDescription(" This table contains the list of configuration errors or\n          warnings the MTA encountered when parsing the\n          configuration file it received from the Provisioning\n          Server.\n          For each error, an entry is created in this table,\n          containing the configuration parameters the MTA rejected\n          and the associated reason (e.g., wrong or unknown OID,\n          inappropriate object values).  If the MTA\n          did not report a provisioning state of 'pass(1)' in\n          the pktcMtaDevProvisioningState object, this table MUST be\n          populated for each error or warning instance.  Even if\n          different parameters share the same error type (e.g., all\n          realm name configuration parameters are invalid), all\n          observed errors or warnings must be reported as\n          different instances.  Errors are placed into the table in\n          no particular order.  The table MUST be cleared each time\n\n\n\n          the MTA reboots.")
pktcMtaDevErrorOidsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 140, 1, 1, 12, 1), ).setIndexNames((0, "PKTC-IETF-MTA-MIB", "pktcMtaDevErrorOidIndex"))
if mibBuilder.loadTexts: pktcMtaDevErrorOidsEntry.setDescription(' This entry contains the necessary information the MTA MUST\n          attempt to provide in case of configuration file errors or\n          warnings.')
pktcMtaDevErrorOidIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 1, 12, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,1024)))
if mibBuilder.loadTexts: pktcMtaDevErrorOidIndex.setDescription(" This object is the index of the MTA configuration error\n          table.  It is an integer value that starts at value '1'\n          and is incremented for each encountered configuration\n          file error or warning.\n\n          The maximum number of errors or warnings that can be\n          recorded in the pktcMtaDevErrorOidsTable is set to 1024 as\n          a configuration file is usually validated by operators\n          before deployment.  Given the possible number of\n          configuration parameter assignments in the MTA\n          configuration file, 1024 is perceived as a sufficient\n          limit even with future extensions.\n\n          If the number of the errors in the configuration file\n          exceeds 1024, all errors beyond the 1024th one MUST\n          be ignored and not be reflected in the\n          pktcMtaDevErrorOidsTable.")
pktcMtaDevErrorOid = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 1, 12, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevErrorOid.setDescription(" This object contains a human readable representation\n          (character string) of the OID corresponding to the\n          configuration file parameter that caused the particular\n          error.\n          For example, if the value of the pktcMtaDevEnabled object\n          in the configuration file caused an error, then this\n          object instance will contain the human-readable string of\n          '1.3.6.1.2.1.140.1.1.6.0'.\n          If the MTA generated an error because it was not able\n          to recognize a particular OID, then this object\n          instance would contain an empty value (zero-length\n          string).\n          For example, if the value of an OID in the configuration\n          file was interpreted by the MTA as being 1.2.3.4.5, and if\n          the MTA was not able to recognize this OID as a valid one,\n          this object instance will contain a zero-length string.\n\n          If the number of errors in the configuration file exceeds\n          1024, then for all subsequent errors, the\n          pktcMtaDevErrorOid of the table's 1024th entry MUST\n          contain a human-readable representation of the\n          pktcMtaDevErrorsTooManyErrors object; i.e., the string\n          '1.3.6.1.2.1.140.1.1.4.1.0'.\n          Note that the syntax of this object is SnmpAdminString\n          instead of OBJECT IDENTIFIER because the object value may\n          not be a valid OID due to human or configuration tool\n          encoding errors.")
pktcMtaDevErrorValue = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 1, 12, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevErrorValue.setDescription(" This object contains the value of the OID corresponding to\n          the configuration file parameter that caused the error.\n          If the MTA cannot recognize the OID of the\n          configuration parameter causing the error, then this\n          object instance contains the OID itself as interpreted\n          by the MTA in human-readable representation.\n          If the MTA can recognize the OID but generate an error due\n          to a wrong value of the parameter, then the object\n\n\n\n          instance contains the erroneous value of the parameter as\n          read from the configuration file.\n          In both cases, the value of this object must be\n          represented in human-readable form as a character string.\n          For example, if the value of the pktcMtaDevEnabled object\n          in the configuration file was 3 (invalid value), then the\n          pktcMtaDevErrorValue object instance will contain the\n          human-readable (string) representation of value '3'.\n          Similarly, if the OID in the configuration file has been\n          interpreted by the MTA as being 1.2.3.4.5 and the MTA\n          cannot recognize this OID as a valid one, then this\n          pktcMtaDevErrorValue object instance will contain human\n          readable (string) representation of value '1.2.3.4.5'.\n\n          If the number of errors in the configuration file exceeds\n          1024, then for all subsequent errors, the\n          pktcMtaDevErrorValue of the table's 1024th entry MUST\n          contain a human-readable representation of the\n          pktcMtaDevErrorsTooManyErrors object; i.e., the string\n          '1.3.6.1.2.1.140.1.1.4.1.0'.")
pktcMtaDevErrorReason = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 1, 12, 1, 4), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevErrorReason.setDescription(" This object indicates the reason for the error or warning,\n          as per the MTA's interpretation, in human-readable form.\n          For example:\n          'VALUE NOT IN RANGE', 'VALUE DOES NOT MATCH TYPE',\n          'UNSUPPORTED VALUE', 'LAST 4 BITS MUST BE SET TO ZERO',\n          'OUT OF MEMORY - CANNOT STORE'.\n          This object may also contain vendor specific errors for\n          private vendor OIDs and any proprietary error codes or\n          messages that can help diagnose configuration errors.\n\n          If the number of errors in the configuration file exceeds\n          1024, then for all subsequent errors, the\n          pktcMtaDevErrorReason of the table's 1024th entry MUST\n          contain a human-readable string indicating the reason\n          for an error; for example,\n          'Too many errors in the configuration file'.")
pktcMtaDevDhcpServerAddressType = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 1), InetAddressType().clone('ipv4')).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevDhcpServerAddressType.setDescription(' This object contains the Internet address type for the\n          PacketCable DHCP servers specified in MTA MIB.')
pktcMtaDevServerDhcp1 = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 2), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevServerDhcp1.setDescription(" This object contains the Internet Address of the primary\n          DHCP server the MTA uses during provisioning.\n          The type of this address is determined by the value of\n          the pktcMtaDevDhcpServerAddressType object.\n          When the latter has the value 'ipv4(1)', this object\n          contains the IP address of the primary DHCP\n          server.  It is provided by the CM to the MTA via the DHCP\n          option code 122, sub-option 1, as defined in RFC 3495.\n\n          The behavior of this object when the value of\n          pktcMtaDevDhcpServerAddressType is other than 'ipv4(1)'\n          is not presently specified, but it may be specified\n          in future versions of this MIB module.\n          If this object is of value\n          0.0.0.0, the MTA MUST stop all provisioning\n          attempts, as well as all other activities.\n          If this object is of value 255.255.255.255, it means\n          that there was no preference given for the primary\n          DHCP server, and, the MTA must follow the logic of\n          RFC2131, and the value of DHCP option 122,\n          sub-option 2, must be ignored.")
pktcMtaDevServerDhcp2 = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevServerDhcp2.setDescription(" This object contains the Internet Address of the secondary\n          DHCP server the MTA uses during provisioning.\n          The type of this address is determined by the value of\n          the pktcMtaDevDhcpServerAddressType object.\n          When the latter has the value 'ipv4(1)', this object\n          contains the IP address of the secondary DHCP\n          server.  It is provided by the CM to the MTA via the DHCP\n          option code 122, sub-option 2, as defined in RFC 3495.\n\n          The behavior of this object when the value of\n          pktcMtaDevDhcpServerAddressType is other than 'ipv4(1)'\n          is not presently specified, but it may be specified\n          in future versions of this MIB module.\n          If there was no secondary DHCP server provided in DHCP\n          Option 122, sub-option 2, this object must return the value\n          0.0.0.0.")
pktcMtaDevDnsServerAddressType = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 4), InetAddressType().clone('ipv4')).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevDnsServerAddressType.setDescription(' This object contains the Internet address type for the\n          PacketCable DNS servers specified in MTA MIB.')
pktcMtaDevServerDns1 = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 5), InetAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevServerDns1.setDescription(" This object contains the IP Address of the primary\n          DNS server to be used by the MTA.  The type of this address\n          is determined by the value of the\n          pktcMtaDevDnsServerAddressType object.\n          When the latter has the value 'ipv4(1)', this object\n          contains the IP address of the primary DNS server.\n          As defined in RFC 2132, PacketCable-compliant MTAs receive\n          the IP addresses of the DNS Servers in DHCP option 6.\n          The behavior of this object when the value of\n          pktcMtaDevDnsServerAddressType is other than 'ipv4(1)'\n\n\n\n          is not presently specified, but it may be specified\n          in future versions of this MIB module.\n          If a value is written into an instance of\n          pktcMtaDevServerDns1, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevServerDns2 = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 6), InetAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevServerDns2.setDescription(" This object contains the IP Address of the secondary\n          DNS server to be used by the MTA.  The type of this address\n          is determined by the value of the\n          pktcMtaDevDnsServerAddressType object.\n          When the latter has the value 'ipv4(1)', this object\n          contains the IP address of the secondary DNS\n          server.  As defined in RFC 2132, PacketCable-compliant MTAs\n          receive the IP addresses of the DNS Servers in DHCP\n          option 6.\n          The behavior of this object when the value of\n          pktcMtaDevDnsServerAddressType is other than 'ipv4(1)'\n          is not presently specified, but it may be specified\n          in future versions of this MIB module.\n          If a value is written into an instance of\n          pktcMtaDevServerDns2, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevTimeServerAddressType = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 7), InetAddressType().clone('ipv4')).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevTimeServerAddressType.setDescription(' This object contains the Internet address type for the\n          PacketCable Time servers specified in MTA MIB.')
pktcMtaDevTimeServer = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 8), InetAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevTimeServer.setDescription(" This object contains the Internet Address of the Time\n          Server used by an S-MTA for Time Synchronization.  The type\n          of this address is determined by the value of the\n          pktcMtaDevTimeServerAddressType object.\n          When the latter has the value 'ipv4(1)', this object\n          contains the IP address of the Time Server used for Time\n          Synchronization.\n          In the case of an S-MTA, this object must be\n          populated with a value other than 0.0.0.0 as obtained\n          from DHCP option 4.  The protocol by which the time of day\n          MUST be retrieved is defined in RFC 868.\n          In the case of an E-MTA, this object must contain a\n          value of 0.0.0.0 if the address type is 'ipv4(1)' since\n          an E-MTA does not use the Time Protocol for time\n          synchronization (an E-MTA uses the time retrieved by the\n          DOCSIS cable modem).\n          The behavior of this object when the value of\n          pktcMtaDevTimeServerAddressType is other than 'ipv4(1)'\n          is not presently specified, but it may be specified in\n          future versions of this MIB module.\n          If a value is written into an instance of\n          pktcMtaDevTimeServer, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevConfigFile = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 9), SnmpAdminString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevConfigFile.setDescription(" This object specifies the MTA device configuration file\n          information, including the access method, the server name,\n          and the configuration file name.  The value of this object\n          is the Uniform Resource Locator (URL) of the configuration\n          file for TFTP or HTTP download.\n          If this object value is a TFTP URL, it must be formatted\n          as defined in RFC 3617.\n          If this object value is an HTTP URL, it must be formatted\n          as defined in RFC 2616.\n          If the MTA SNMP Enrollment mechanism is used, then the MTA\n          must download the file provided by the Provisioning Server\n\n\n\n          during provisioning via an SNMP SET on this object.\n          If the MTA SNMP Enrollment mechanism is not used, this\n          object MUST contain the URL value corresponding to the\n          'siaddr' and 'file' fields received in the DHCP ACK to\n          locate the configuration file: the 'siaddr' and 'file'\n          fields represent the host and file of the TFTP URL,\n          respectively.  In this case, the MTA MUST return an\n          'inconsistentValue' error in response to SNMP SET\n          operations.\n          The MTA MUST return a zero-length string if the server\n          address (host part of the URL) is unknown.\n          If a value is written into an instance of\n          pktcMtaDevConfigFile, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevSnmpEntity = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 10), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevSnmpEntity.setDescription(' This object contains the FQDN of the SNMP entity of the\n          Provisioning Server.  When the MTA SNMP Enrollment\n          Mechanism is used, this object represents the server that\n          the MTA communicates with, that it receives the\n          configuration file URL from, and that it sends the\n          enrollment notification to.  The SNMP entity is also the\n          destination entity for all the provisioning\n          notifications.  It may be used for post-provisioning\n          SNMP operations.  During the provisioning phase, this\n          SNMP entity FQDN is supplied to the MTA via DHCP option\n          122, sub-option 3, as defined in RFC 3495.  The MTA must\n          resolve the FQDN value before its very first network\n          interaction with the SNMP entity during the provisioning\n          phase.')
pktcMtaDevProvConfigHash = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 11), OctetString().subtype(subtypeSpec=ValueSizeConstraint(20,20)).setFixedLength(20)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevProvConfigHash.setDescription(" This object contains the hash value of the contents of the\n          configuration file.\n          The authentication algorithm is Secure Hashing Algorithm\n          1 (SHA-1), and the length is 160 bits.  The hash\n          calculation MUST follow the requirements defined in the\n          PacketCable Security Specification.  When the MTA SNMP\n          Enrollment mechanism is used, this hash value is\n          calculated and sent to the MTA prior to sending the\n          config file.  This object value is then provided by the\n          Provisioning server via an SNMP SET operation.\n          When the MTA SNMP Enrollment mechanism is not in use, the\n          hash value is provided in the configuration file itself,\n          and it is also calculated by the MTA.  This object value\n          MUST represent the hash value calculated by the MTA.\n          When the MTA SNMP Enrollment mechanism is not in use, the\n          MTA must reject all SNMP SET operations on this object and\n          return an 'inconsistentValue' error.\n          If a value is written into an instance of\n          pktcMtaDevProvConfigHash, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevProvConfigKey = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 12), OctetString().subtype(subtypeSpec=ValueSizeConstraint(32,32)).setFixedLength(32)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevProvConfigKey.setDescription(" This object contains the key used to encrypt/decrypt\n          the configuration file when secure SNMPv3 provisioning\n          is used.\n          The value of this object is provided along with the\n          configuration file information (pktcMtaDevConfigFile)\n          and hash (pktcMtaDevProvConfigHash) by the Provisioning\n          Server via SNMP SET once the configuration file has been\n          created, as defined by the PacketCable Security\n          specification.\n\n          The privacy algorithm is defined by the\n          pktcMtaDevProvConfigEncryptAlg MIB object.  The\n          MTA requirements related to the privacy algorithm are\n          defined in the PacketCable Security Specification.\n\n          If this object is set at any other provisioning step than\n          that allowed by the PacketCable MTA Device\n\n\n\n          Provisioning Specification, the MTA SHOULD return\n          an 'inconsistentValue' error.\n          This object must not be used in non secure provisioning\n          mode.  In non-secure provisioning modes, the MTA SHOULD\n          return an 'inconsistentValue' in response to SNMP SET\n          operations, and the MTA SHOULD return a zero-length\n          string in response to SNMP GET operations.\n          If a value is written into an instance of\n          pktcMtaDevProvConfigKey, the agent MUST NOT retain the\n          supplied value across MTA re-initializations or reboots.")
pktcMtaDevProvConfigEncryptAlg = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 13), PktcMtaDevProvEncryptAlg().clone('des64CbcMode')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevProvConfigEncryptAlg.setDescription(' This object defines the encryption algorithm used for\n          privacy protection of the MTA Configuration File content.')
pktcMtaDevProvSolicitedKeyTimeout = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 14), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,180)).clone(3)).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevProvSolicitedKeyTimeout.setDescription(" This object defines a Kerberos Key Management timer on the\n          MTA.  It is the time period during which the MTA saves the\n          nonce and Server Kerberos Principal Identifier to match an\n          AP Request and its associated AP Reply response from the\n          Provisioning Server.\n          After the timeout has been exceeded, the client discards\n          this (nonce, Server Kerberos Principal Identifier) pair,\n          after which it will no longer accept a matching AP Reply.\n          This timer only applies when the Provisioning Server\n          initiated key management for SNMPv3 (with a\n          Wake Up message).\n          If this object is set to a zero value, the MTA MUST return\n          an 'inconsistentValue' in response to SNMP SET operations.\n          This object should not be used in non-secure provisioning\n          modes.  In non-secure provisioning modes, the MTA MUST\n          return an 'inconsistentValue' in response to SNMP SET\n          operations, and the MTA MUST return a zero value in\n\n\n\n          response to SNMP GET operations.\n          If a value is written into an instance of\n          pktcMtaDevProvSolicitedKeyTimeout, the agent MUST NOT\n          retain the supplied value across MTA re-initializations\n          or reboots.")
pktcMtaDevProvUnsolicitedKeyMaxTimeout = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,600)).clone(600)).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvUnsolicitedKeyMaxTimeout.setDescription(' This object defines the timeout value that applies to\n          an MTA-initiated AP-REQ/REP key management exchange with\n          the Provisioning Server in SNMPv3 provisioning.\n          It is the maximum timeout value, and it may not be exceeded\n          in the exponential back-off algorithm.  If the DHCP option\n\n\n\n          code 122, sub-option 5, is provided to the MTA, it\n          overwrites this value.\n          In non-secure provisioning modes, the MTA MUST\n          return a zero value in response to SNMP GET\n          operations.')
pktcMtaDevProvUnsolicitedKeyNomTimeout = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 16), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,600)).clone(3)).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvUnsolicitedKeyNomTimeout.setDescription(' This object defines the starting value of the timeout\n          for the AP-REQ/REP Backoff and Retry mechanism\n          with exponential timeout in SNMPv3 provisioning.\n          If the DHCP option code 122, sub-option 5, is provided\n          the MTA, it overwrites this value.\n          In non-secure provisioning modes, the MTA MUST\n          return a zero value in response to SNMP GET\n          operations.')
pktcMtaDevProvUnsolicitedKeyMaxRetries = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 17), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,32)).clone(8)).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvUnsolicitedKeyMaxRetries.setDescription(" This object contains a retry counter that applies to\n          an MTA-initiated AP-REQ/REP key management exchange with\n          the Provisioning Server in secure SNMPv3 provisioning.\n          It is the maximum number of retries before the MTA stops\n          attempting to establish a Security Association with\n          Provisioning Server.\n          If the DHCP option code 122, sub-option 5, is provided to\n          the MTA, it overwrites this value.\n          If this object is set to a zero value, the MTA MUST return\n          an 'inconsistentValue' in response to SNMP SET operations.\n          In non-secure provisioning modes, the MTA MUST\n          return a zero value in response to SNMP GET\n          operations.")
pktcMtaDevProvKerbRealmName = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 18), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvKerbRealmName.setDescription(' This object contains the name of the associated\n          provisioning Kerberos realm acquired during the MTA4\n          provisioning step (DHCP Ack) for SNMPv3 provisioning.\n          The uppercase ASCII representation of the associated\n          Kerberos realm name MUST be used by both the Manager (SNMP\n          entity) and the MTA.\n          The Kerberos realm name for the Provisioning Server is\n          supplied to the MTA via DHCP option code 122, sub-option 6,\n          as defined in RFC 3495.  In secure SNMP provisioning mode,\n          the value of the Kerberos realm name for the Provisioning\n          Server supplied in the MTA configuration file must match\n          the value supplied in the DHCP option code 122,\n          sub-option 6.  Otherwise, the value of this object must\n          contain the value supplied in DHCP Option 122,\n          sub-option 6.')
pktcMtaDevProvState = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 2, 19), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4,)).clone(namedValues=NamedValues(("operational", 1), ("waitingForSnmpSetInfo", 2), ("waitingForTftpAddrResponse", 3), ("waitingForConfigFile", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevProvState.setDescription(" This object defines the MTA provisioning state.\n          If the state is:\n\n            'operational(1)', the device has completed the loading\n             and processing of the initialization parameters.\n\n            'waitingForSnmpSetInfo(2)', the device is waiting on\n             its configuration file download access information.\n             Note that this state is only reported when the MTA\n\n\n\n             SNMP enrollment mechanism is used.\n\n            'waitingForTftpAddrResponse(3)', the device has sent a\n             DNS request to resolve the server providing the\n             configuration file, and it is awaiting for a response.\n             Note that this state is only reported when the MTA\n             SNMP enrollment mechanism is used.\n\n            'waitingForConfigFile(4)', the device has sent a\n            request via TFTP or HTTP for the download of its\n            configuration file, and it is awaiting for a response or\n            the file download is in progress.")
pktcMtaDevManufacturerCertificate = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 1), DocsX509ASN1DEREncodedCertificate()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevManufacturerCertificate.setDescription(" This object contains the MTA Manufacturer Certificate.\n          The object value must be the ASN.1 DER encoding of the MTA\n          manufacturer's X.509 public key certificate.  The MTA\n          Manufacturer Certificate is issued to each MTA\n          manufacturer and is installed into each MTA at the time of\n          manufacture or with a secure code download.  The specific\n          requirements related to this certificate are defined in\n          the PacketCable or IPCablecom Security specifications.")
pktcMtaDevCertificate = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 2), DocsX509ASN1DEREncodedCertificate()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevCertificate.setDescription(" This object contains the MTA Device Certificate.\n          The object value must be the ASN.1 DER encoding of the\n          MTA's X.509 public-key certificate issued by the\n          manufacturer and installed into the MTA at the time of\n\n\n\n          manufacture or with a secure code download.\n          This certificate contains the MTA MAC address.  The\n          specific requirements related to this certificate are\n          defined in the PacketCable or IPCablecom Security\n          specifications.")
pktcMtaDevCorrelationId = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevCorrelationId.setDescription(' This object contains a correlation ID, an arbitrary value\n          generated by the MTA that will be exchanged as part of the\n          device capability data to the Provisioning Application.\n          This random value is used as an identifier to correlate\n          related events in the MTA provisioning sequence.\n          This value is intended for use only during the MTA\n          initialization and configuration file download.')
pktcMtaDevTelephonyRootCertificate = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 4), DocsX509ASN1DEREncodedCertificate()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevTelephonyRootCertificate.setDescription(' This object contains the telephony Service Provider Root\n          certificate.  The object value is the ASN.1 DER encoding of\n          the IP Telephony Service Provider Root X.509 public key\n          certificate.  This certification is stored in the MTA\n          non-volatile memory and can be updated with a secure code\n          download.  This certificate is used to validate the initial\n          AS Reply received by the MTA from the Key Distribution\n          Center (KDC) during the MTA initialization.  The specific\n          requirements related to this certificate are defined in\n          the PacketCable or IPCablecom Security specifications.')
pktcMtaDevRealmAvailSlot = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevRealmAvailSlot.setDescription(" This object contains the index number of the first\n          available entry in the realm table (pktcMtaDevRealmTable).\n          If all the entries in the realm table have been assigned,\n          this object contains the value of zero.\n          A management station should create new entries in the\n          realm table, using the following procedure:\n\n          First, issue a management protocol retrieval operation\n          to determine the value of the first available index in the\n          realm table (pktcMtaDevRealmAvailSlot).\n\n          Second, issue a management protocol SET operation\n          to create an instance of the pktcMtaDevRealmStatus\n          object by setting its value to 'createAndWait(5)'.\n\n          Third, if the SET operation succeeded, continue\n          modifying the object instances corresponding to the newly\n          created conceptual row, without fear of collision with\n          other management stations.  When all necessary conceptual\n          columns of the row are properly populated (via SET\n          operations or default values), the management station may\n          SET the pktcMtaDevRealmStatus object to 'active(1)'.")
pktcMtaDevRealmTable = MibTable((1, 3, 6, 1, 2, 1, 140, 1, 3, 6), )
if mibBuilder.loadTexts: pktcMtaDevRealmTable.setDescription(' This object contains the realm table.\n          The CMS table (pktcMtaDevCmsTable) and the realm table\n          (pktcMtaDevRealmTable) are used for managing the MTA-CMS\n          Security Associations.  The realm table defines the\n          Kerberos realms for the Application Servers (CMSes and the\n          Provisioning Server).')
pktcMtaDevRealmEntry = MibTableRow((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1), ).setIndexNames((0, "PKTC-IETF-MTA-MIB", "pktcMtaDevRealmIndex"))
if mibBuilder.loadTexts: pktcMtaDevRealmEntry.setDescription(' This table entry object lists the MTA security parameters\n          for a single Kerberos realm.  The conceptual rows MUST NOT\n          persist across MTA reboots.')
pktcMtaDevRealmIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,64)))
if mibBuilder.loadTexts: pktcMtaDevRealmIndex.setDescription(' This object defines the realm table index.')
pktcMtaDevRealmName = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmName.setDescription(' This object identifies the Kerberos realm name in all\n          capitals.  The MTA MUST prohibit the instantiation of any\n          two rows with identical Kerberos realm names.  The MTA MUST\n          also verify that any search operation involving Kerberos\n          realm names is done using the uppercase ASCII\n          representation of the characters.')
pktcMtaDevRealmPkinitGracePeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(15,600)).clone(15)).setUnits('minutes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmPkinitGracePeriod.setDescription(' This object contains the PKINIT Grace Period.  For the\n         purpose of key management with Application Servers (CMSes\n\n\n\n         or the Provisioning Server), the MTA must utilize the\n         PKINIT exchange to obtain Application Server tickets.  The\n         MTA may utilize the PKINIT exchange to obtain Ticket\n         Granting Tickets (TGTs), which are then used to obtain\n         Application Server tickets in a TGS exchange.\n         The PKINIT exchange occurs according to the current Ticket\n         Expiration Time (TicketEXP) and on the PKINIT Grace Period\n         (PKINITGP).  The MTA MUST initiate the PKINIT exchange at\n         the time: TicketEXP - PKINITGP.')
pktcMtaDevRealmTgsGracePeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,600)).clone(10)).setUnits('minutes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmTgsGracePeriod.setDescription(' This object contains the Ticket Granting Server Grace\n          Period (TGSGP).  The Ticket Granting Server (TGS)\n          Request/Reply exchange may be performed by the MTA\n          on demand whenever an Application Server ticket is\n          needed to establish security parameters.  If the MTA\n          possesses a ticket that corresponds to the Provisioning\n          Server or a CMS that currently exists in the CMS table,\n          the MTA MUST initiate the TGS Request/Reply exchange\n          at the time: TicketEXP - TGSGP.')
pktcMtaDevRealmOrgName = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 5), LongUtf8String()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmOrgName.setDescription(' This object contains the X.500 organization name attribute\n          as defined in the subject name of the service provider\n          certificate.')
pktcMtaDevRealmUnsolicitedKeyMaxTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,600)).clone(100)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmUnsolicitedKeyMaxTimeout.setDescription(' This object specifies the maximum time the MTA will\n          attempt to perform the exponential back-off algorithm.\n          This timer only applies when the MTA initiated key\n          management.  If the DHCP option code 122, sub-option 4, is\n          provided to the MTA, it overwrites this value.\n\n          Unsolicited key updates are retransmitted according to an\n          exponential back-off mechanism using two timers and a\n          maximum retry counter for AS replies.\n          The initial retransmission timer value is the nominal\n          timer value (pktcMtaDevRealmUnsolicitedKeyNomTimeout).  The\n          retransmissions occur with an exponentially increasing\n          interval that caps at the maximum timeout value\n          (pktcMtaDevRealmUnsolicitedKeyMaxTimeout).\n          Retransmissions stop when the maximum retry counter is\n          reached (pktcMatDevRealmUnsolicitedMaxRetries).\n\n          For example, with values of 3 seconds for the nominal\n          timer, 20 seconds for the maximum timeout, and 5 retries\n          max, retransmission intervals will be 3 s, 6 s,\n          12 s, 20 s, and 20 s, and retransmissions then stop because\n          the maximum number of retries has been reached.')
pktcMtaDevRealmUnsolicitedKeyNomTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(100,600000)).clone(3000)).setUnits('milliseconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmUnsolicitedKeyNomTimeout.setDescription(' This object specifies the initial timeout value\n          for the AS-REQ/AS-REP exponential back-off and retry\n          mechanism.  If the DHCP option code 122, sub-option 4, is\n          provided to the MTA, it overwrites this value.\n          This value should account for the average roundtrip\n          time between the MTA and the KDC, as well as the\n          processing delay on the KDC.\n\n\n\n\n          Unsolicited key updates are retransmitted according to an\n          exponential back-off mechanism using two timers and a\n          maximum retry counter for AS replies.\n          The initial retransmission timer value is the nominal\n          timer value (pktcMtaDevRealmUnsolicitedKeyNomTimeout).  The\n          retransmissions occur with an exponentially increasing\n          interval that caps at the maximum timeout value\n          (pktcMtaDevRealmUnsolicitedKeyMaxTimeout).\n          Retransmissions stop when the maximum retry counter is\n          reached (pktcMatDevRealmUnsolicitedMaxRetries).\n\n          For example, with values of 3 seconds for the nominal\n          timer, 20 seconds for the maximum timeout, and 5 retries\n          max, in retransmission intervals will be 3 s, 6 s,\n          12 s, 20 s, and 20 s; retransmissions then stop because\n          the maximum number of retries has been reached.')
pktcMtaDevRealmUnsolicitedKeyMaxRetries = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,1024)).clone(5)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmUnsolicitedKeyMaxRetries.setDescription(' This object specifies the maximum number of retries the\n          MTA attempts to obtain a ticket from the KDC.\n\n          Unsolicited key updates are retransmitted according to an\n          exponential back-off mechanism using two timers and a\n          maximum retry counter for AS replies.\n          The initial retransmission timer value is the nominal\n          timer value (pktcMtaDevRealmUnsolicitedKeyNomTimeout).  The\n          retransmissions occur with an exponentially increasing\n          interval that caps at the maximum timeout value\n          (pktcMtaDevRealmUnsolicitedKeyMaxTimeout).\n          Retransmissions stop when the maximum retry counter is\n          reached (pktcMatDevRealmUnsolicitedMaxRetries).\n\n          For example, with values of 3 seconds for the nominal\n          timer, 20 seconds for the maximum timeout, and 5 retries\n          max, retransmission intervals will be 3 s, 6 s,\n          12 s, 20 s, and 20 s; retransmissions then stop because\n          the maximum number of retries has been reached.')
pktcMtaDevRealmStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 6, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevRealmStatus.setDescription(" This object defines the row status of this realm in the\n          realm table (pktcMtaDevRealmTable).\n\n          An entry in this table is not qualified for activation\n          until the object instances of all corresponding columns\n          have been initialized, either by default values, or via\n          explicit SET operations.  Until all object instances in\n          this row are initialized, the status value for this realm\n          must be 'notReady(3)'.\n          In particular, two columnar objects must be explicitly\n          SET: the realm name (pktcMtaDevRealmName) and the\n          organization name (pktcMtaDevRealmOrgName).  Once these 2\n          objects have been set and the row status is SET to\n          'active(1)', the MTA MUST NOT allow any modification of\n          these 2 object values.\n          The value of this object has no effect on whether other\n          columnar objects in this row can be modified.")
pktcMtaDevCmsAvailSlot = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevCmsAvailSlot.setDescription(" This object contains the index number of the first\n          available entry in the CMS table (pktcMtaDevCmsTable).\n          If all the entries in the CMS table have been assigned,\n          this object contains the value of zero.\n          A management station should create new entries in the\n          CMS table, using the following procedure:\n\n          First, issue a management protocol retrieval operation\n          to determine the value of the first available index in the\n          CMS table (pktcMtaDevCmsAvailSlot).\n\n          Second, issue a management protocol SET operation\n          to create an instance of the pktcMtaDevCmsStatus\n          object by setting its value to 'createAndWait(5)'.\n\n          Third, if the SET operation succeeded, continue\n          modifying the object instances corresponding to the newly\n          created conceptual row, without fear of collision with\n          other management stations.  When all necessary conceptual\n          columns of the row are properly populated (via SET\n          operations or default values), the management station may\n          SET the pktcMtaDevCmsStatus object to 'active(1)'.")
pktcMtaDevCmsTable = MibTable((1, 3, 6, 1, 2, 1, 140, 1, 3, 8), )
if mibBuilder.loadTexts: pktcMtaDevCmsTable.setDescription(' This object defines the CMS table.\n          The CMS table (pktcMtaDevCmsTable) and the realm table\n          (pktcMtaDevRealmTable) are used for managing security\n          between the MTA and CMSes.  Each CMS table entry defines\n          a CMS the managed MTA is allowed to communicate with\n          and contains security parameters for key management with\n          that CMS.')
pktcMtaDevCmsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1), ).setIndexNames((0, "PKTC-IETF-MTA-MIB", "pktcMtaDevCmsIndex"))
if mibBuilder.loadTexts: pktcMtaDevCmsEntry.setDescription(' This table entry object lists the MTA key management\n          parameters used when establishing Security Associations\n          with a CMS.  The conceptual rows MUST NOT persist across\n          MTA reboots.')
pktcMtaDevCmsIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,128)))
if mibBuilder.loadTexts: pktcMtaDevCmsIndex.setDescription(' This object defines the CMS table index.')
pktcMtaDevCmsFqdn = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsFqdn.setDescription(' This object specifies the CMS FQDN.  The MTA must\n          prohibit the instantiation of any two rows with identical\n          FQDNs.  The MTA must also verify that any search and/or\n          comparison operation involving a CMS FQDN is case\n          insensitive.  The MTA must resolve the CMS FQDN as required\n           by the corresponding PacketCable Specifications.')
pktcMtaDevCmsKerbRealmName = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 3), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsKerbRealmName.setDescription(' This object identifies the Kerberos realm name in uppercase\n          characters associated with the CMS defined in this\n\n\n\n          conceptual row.  The object value is a reference\n          point to the corresponding Kerberos realm name in the\n          realm table (pktcMtaDevRealmTable).')
pktcMtaDevCmsMaxClockSkew = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,1800)).clone(300)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsMaxClockSkew.setDescription(' This object specifies the maximum allowable clock skew\n          between the MTA and the CMS defined in this row.')
pktcMtaDevCmsSolicitedKeyTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(100,30000)).clone(1000)).setUnits('milliseconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsSolicitedKeyTimeout.setDescription(' This object defines a Kerberos Key Management timer on the\n          MTA.  It is the time period during which the MTA saves the\n          nonce and Server Kerberos Principal Identifier to match an\n          AP Request and its associated AP Reply response from the\n          CMS.  This timer only applies when the CMS initiated key\n          management (with a Wake Up message or a Rekey message).')
pktcMtaDevCmsUnsolicitedKeyMaxTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,600)).clone(600)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsUnsolicitedKeyMaxTimeout.setDescription(' This object defines the timeout value that only applies\n          to an MTA-initiated key management exchange.  It is the\n          maximum timeout, and it may not be exceeded in the\n          exponential back-off algorithm.')
pktcMtaDevCmsUnsolicitedKeyNomTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(100,30000)).clone(500)).setUnits('milliseconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsUnsolicitedKeyNomTimeout.setDescription(' This object defines the starting value of the timeout\n          for an MTA-initiated key management.  It should account for\n          the average roundtrip time between the MTA and the CMS and\n          the processing time on the CMS.')
pktcMtaDevCmsUnsolicitedKeyMaxRetries = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,1024)).clone(5)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsUnsolicitedKeyMaxRetries.setDescription(' This object contains the maximum number of retries before\n          the MTA stops attempting to establish a Security\n          Association with the CMS.')
pktcMtaDevCmsIpsecCtrl = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 9), TruthValue().clone('true')).setMaxAccess("readonly")
if mibBuilder.loadTexts: pktcMtaDevCmsIpsecCtrl.setDescription(" This object specifies the MTA IPSec control flag.\n          If the object value is 'true', the MTA must use Kerberos\n          Key Management and IPsec to communicate with this CMS.  If\n          it is 'false', IPSec Signaling Security and Kerberos key\n          management are disabled for this specific CMS.")
pktcMtaDevCmsStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 140, 1, 3, 8, 1, 10), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pktcMtaDevCmsStatus.setDescription(" This object defines the row status associated with this\n          particular CMS in the CMS table (pktcMtaDevCmsTable).\n\n          An entry in this table is not qualified for activation\n          until the object instances of all corresponding columns\n          have been initialized, either by default values or via\n          explicit SET operations.  Until all object instances in\n          this row are initialized, the status value for this realm\n          must be 'notReady(3)'.\n          In particular, two columnar objects must be SET: the\n          CMS FQDN (pktcMtaDevCmsFqdn) and the Kerberos realm name\n          (pktcMtaDevCmsKerbRealmName).  Once these 2 objects have\n          been set and the row status is SET to 'active(1)', the MTA\n          MUST NOT allow any modification of these 2 object values.\n\n          The value of this object has no effect on\n          whether other columnar objects in this row can be\n          modified.")
pktcMtaDevResetKrbTickets = MibScalar((1, 3, 6, 1, 2, 1, 140, 1, 3, 9), Bits().clone(namedValues=NamedValues(("invalidateProvOnReboot", 0), ("invalidateAllCmsOnReboot", 1),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pktcMtaDevResetKrbTickets.setDescription(" This object defines a Kerberos Ticket Control Mask that\n          instructs the MTA to invalidate the specific Application\n\n\n\n          Server Kerberos ticket(s) that are stored locally in the\n          MTA NVRAM (non-volatile or persistent memory).\n          If the MTA does not store Kerberos tickets in NVRAM, it\n          MUST ignore setting of this object and MUST report a BITS\n          value of zero when the object is read.\n          If the MTA supports Kerberos tickets storage in NVRAM, the\n          object value is encoded as follows:\n          - Setting the invalidateProvOnReboot bit (bit 0) to 1\n            means that the MTA MUST invalidate the Kerberos\n            Application Ticket(s) for the Provisioning Application\n            at the next MTA reboot if secure SNMP provisioning mode\n            is used.  In non-secure provisioning modes, the MTA MUST\n            return an 'inconsistentValue' in response to SNMP SET\n            operations with a bit 0 set to 1.\n          - Setting the invalidateAllCmsOnReboot bit (bit 1) to 1\n            means that the MTA MUST invalidate the Kerberos\n            Application Ticket(s) for all CMSes currently assigned\n            to the MTA endpoints.\n          If a value is written into an instance of\n          pktcMtaDevResetKrbTickets, the agent MUST retain the\n          supplied value across an MTA re-initialization or\n          reboot.")
pktcMtaDevErrorsTooManyErrors = ObjectIdentity((1, 3, 6, 1, 2, 1, 140, 1, 4, 1))
if mibBuilder.loadTexts: pktcMtaDevErrorsTooManyErrors.setDescription('This object defines the OID corresponding to the error\n         condition when too many errors are encountered in the\n         MTA configuration file during provisioning.')
pktcMtaDevProvisioningEnrollment = NotificationType((1, 3, 6, 1, 2, 1, 140, 0, 1)).setObjects(*(("PKTC-IETF-MTA-MIB", "sysDescr"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevSwCurrentVers"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevTypeIdentifier"), ("PKTC-IETF-MTA-MIB", "ifPhysAddress"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCorrelationId"),))
if mibBuilder.loadTexts: pktcMtaDevProvisioningEnrollment.setDescription(' This INFORM notification is issued by the MTA to initiate\n          the PacketCable provisioning process when the MTA SNMP\n          enrollment mechanism is used.\n          It contains the system description, the current software\n          version, the MTA device type identifier, the MTA MAC\n          address (obtained in the MTA ifTable in the ifPhysAddress\n          object that corresponds to the ifIndex 1), and a\n          correlation ID.')
pktcMtaDevProvisioningStatus = NotificationType((1, 3, 6, 1, 2, 1, 140, 0, 2)).setObjects(*(("PKTC-IETF-MTA-MIB", "ifPhysAddress"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCorrelationId"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningState"),))
if mibBuilder.loadTexts: pktcMtaDevProvisioningStatus.setDescription(' This INFORM notification may be issued by the MTA to\n          confirm the completion of the PacketCable provisioning\n          process, and to report its provisioning completion\n          status.\n          It contains the MTA MAC address (obtained in the MTA\n          ifTable in the ifPhysAddress object that corresponds\n          to the ifIndex 1), a correlation ID and the MTA\n          provisioning state as defined in\n          pktcMtaDevProvisioningState.')
pktcMtaCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 2, 1))
pktcMtaGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 140, 2, 2))
pktcMtaBasicCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 140, 2, 1, 1)).setObjects(*(("PKTC-IETF-MTA-MIB", "pktcMtaGroup"), ("PKTC-IETF-MTA-MIB", "pktcMtaNotificationGroup"),))
if mibBuilder.loadTexts: pktcMtaBasicCompliance.setDescription(' The compliance statement for MTA devices that implement\n          PacketCable or IPCablecom requirements.\n\n          This compliance statement applies to MTA implementations\n          that support PacketCable 1.0 or IPCablecom requirements,\n          which are not IPv6-capable at the time of this\n\n\n\n          RFC publication.')
pktcMtaGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 140, 2, 2, 1)).setObjects(*(("PKTC-IETF-MTA-MIB", "pktcMtaDevResetNow"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevSerialNumber"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevSwCurrentVers"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevFQDN"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevEndPntCount"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevEnabled"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningCounter"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevErrorOid"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevErrorValue"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevErrorReason"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevTypeIdentifier"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningState"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevHttpAccess"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCertificate"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCorrelationId"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevManufacturerCertificate"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevDhcpServerAddressType"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevDnsServerAddressType"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevTimeServerAddressType"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvConfigEncryptAlg"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevServerDhcp1"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevServerDhcp2"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevServerDns1"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevServerDns2"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevTimeServer"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevConfigFile"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevSnmpEntity"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmPkinitGracePeriod"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmTgsGracePeriod"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmAvailSlot"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmName"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmOrgName"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmUnsolicitedKeyMaxTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmUnsolicitedKeyNomTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmUnsolicitedKeyMaxRetries"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevRealmStatus"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsAvailSlot"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsFqdn"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsKerbRealmName"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsUnsolicitedKeyMaxTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsUnsolicitedKeyNomTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsUnsolicitedKeyMaxRetries"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsSolicitedKeyTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsMaxClockSkew"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsIpsecCtrl"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevCmsStatus"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevResetKrbTickets"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvUnsolicitedKeyMaxTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvUnsolicitedKeyNomTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvUnsolicitedKeyMaxRetries"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvKerbRealmName"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvSolicitedKeyTimeout"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvConfigHash"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvConfigKey"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvState"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningTimer"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevTelephonyRootCertificate"),))
if mibBuilder.loadTexts: pktcMtaGroup.setDescription(' A collection of objects for managing PacketCable or\n          IPCablecom MTA implementations.')
pktcMtaNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 140, 2, 2, 2)).setObjects(*(("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningStatus"), ("PKTC-IETF-MTA-MIB", "pktcMtaDevProvisioningEnrollment"),))
if mibBuilder.loadTexts: pktcMtaNotificationGroup.setDescription(' A collection of notifications dealing with the change of\n          MTA provisioning status.')
pktcMtaBasicSmtaCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 140, 2, 1, 2)).setObjects(*(("PKTC-IETF-MTA-MIB", "pktcMtaGroup"), ("PKTC-IETF-MTA-MIB", "pktcMtaNotificationGroup"), ("DOCS-CABLE-DEVICE-MIB", "docsDevSoftwareGroupV2"), ("DOCS-IETF-BPI2-MIB", "docsBpi2CodeDownloadGroup"),))
if mibBuilder.loadTexts: pktcMtaBasicSmtaCompliance.setDescription(' The compliance statement for S-MTA devices\n          that implement PacketCable or IPCablecom requirements.\n\n          This compliance statement applies to S-MTA implementations\n          that support PacketCable or IPCablecom requirements,\n          which are not IPv6-capable at the time of this\n          RFC publication.')
mibBuilder.exportSymbols("PKTC-IETF-MTA-MIB", pktcMtaDevSerialNumber=pktcMtaDevSerialNumber, pktcMtaDevTelephonyRootCertificate=pktcMtaDevTelephonyRootCertificate, PYSNMP_MODULE_ID=pktcIetfMtaMib, pktcMtaDevRealmUnsolicitedKeyMaxTimeout=pktcMtaDevRealmUnsolicitedKeyMaxTimeout, pktcMtaDevTimeServerAddressType=pktcMtaDevTimeServerAddressType, pktcMtaDevCmsStatus=pktcMtaDevCmsStatus, pktcMtaNotification=pktcMtaNotification, pktcMtaDevServerDhcp1=pktcMtaDevServerDhcp1, pktcMtaDevProvisioningTimer=pktcMtaDevProvisioningTimer, pktcMtaDevCmsAvailSlot=pktcMtaDevCmsAvailSlot, pktcMtaDevRealmEntry=pktcMtaDevRealmEntry, pktcMtaDevRealmName=pktcMtaDevRealmName, pktcMtaCompliances=pktcMtaCompliances, pktcMtaDevCertificate=pktcMtaDevCertificate, pktcMtaDevRealmTable=pktcMtaDevRealmTable, pktcMtaDevRealmAvailSlot=pktcMtaDevRealmAvailSlot, pktcMtaDevEnabled=pktcMtaDevEnabled, pktcMtaDevProvUnsolicitedKeyMaxRetries=pktcMtaDevProvUnsolicitedKeyMaxRetries, pktcMtaDevErrorOidsTable=pktcMtaDevErrorOidsTable, pktcMtaDevErrorOidsEntry=pktcMtaDevErrorOidsEntry, PktcMtaDevProvEncryptAlg=PktcMtaDevProvEncryptAlg, pktcMtaDevServer=pktcMtaDevServer, pktcMtaDevProvSolicitedKeyTimeout=pktcMtaDevProvSolicitedKeyTimeout, pktcMtaDevDnsServerAddressType=pktcMtaDevDnsServerAddressType, pktcMtaDevErrorReason=pktcMtaDevErrorReason, pktcMtaDevTimeServer=pktcMtaDevTimeServer, pktcMtaDevResetNow=pktcMtaDevResetNow, pktcMtaMibObjects=pktcMtaMibObjects, pktcMtaDevCmsUnsolicitedKeyNomTimeout=pktcMtaDevCmsUnsolicitedKeyNomTimeout, pktcMtaDevServerDns1=pktcMtaDevServerDns1, pktcMtaBasicSmtaCompliance=pktcMtaBasicSmtaCompliance, pktcMtaDevProvConfigHash=pktcMtaDevProvConfigHash, pktcMtaDevErrorOidIndex=pktcMtaDevErrorOidIndex, pktcMtaDevErrorOid=pktcMtaDevErrorOid, pktcMtaDevErrors=pktcMtaDevErrors, pktcMtaDevProvConfigEncryptAlg=pktcMtaDevProvConfigEncryptAlg, pktcMtaDevHttpAccess=pktcMtaDevHttpAccess, pktcMtaDevSnmpEntity=pktcMtaDevSnmpEntity, pktcMtaDevProvisioningState=pktcMtaDevProvisioningState, pktcMtaDevCmsUnsolicitedKeyMaxRetries=pktcMtaDevCmsUnsolicitedKeyMaxRetries, pktcMtaDevCmsFqdn=pktcMtaDevCmsFqdn, pktcMtaDevRealmUnsolicitedKeyMaxRetries=pktcMtaDevRealmUnsolicitedKeyMaxRetries, pktcMtaDevCmsKerbRealmName=pktcMtaDevCmsKerbRealmName, pktcMtaDevCorrelationId=pktcMtaDevCorrelationId, pktcMtaDevDhcpServerAddressType=pktcMtaDevDhcpServerAddressType, pktcMtaDevProvUnsolicitedKeyMaxTimeout=pktcMtaDevProvUnsolicitedKeyMaxTimeout, pktcMtaDevErrorValue=pktcMtaDevErrorValue, pktcMtaGroup=pktcMtaGroup, pktcMtaDevServerDns2=pktcMtaDevServerDns2, pktcIetfMtaMib=pktcIetfMtaMib, pktcMtaDevManufacturerCertificate=pktcMtaDevManufacturerCertificate, pktcMtaDevProvUnsolicitedKeyNomTimeout=pktcMtaDevProvUnsolicitedKeyNomTimeout, pktcMtaDevRealmPkinitGracePeriod=pktcMtaDevRealmPkinitGracePeriod, pktcMtaDevConfigFile=pktcMtaDevConfigFile, pktcMtaDevTypeIdentifier=pktcMtaDevTypeIdentifier, pktcMtaDevCmsTable=pktcMtaDevCmsTable, pktcMtaDevResetKrbTickets=pktcMtaDevResetKrbTickets, pktcMtaDevRealmTgsGracePeriod=pktcMtaDevRealmTgsGracePeriod, pktcMtaDevProvisioningEnrollment=pktcMtaDevProvisioningEnrollment, pktcMtaGroups=pktcMtaGroups, pktcMtaDevProvConfigKey=pktcMtaDevProvConfigKey, pktcMtaDevCmsMaxClockSkew=pktcMtaDevCmsMaxClockSkew, pktcMtaDevSecurity=pktcMtaDevSecurity, pktcMtaDevEndPntCount=pktcMtaDevEndPntCount, pktcMtaDevRealmStatus=pktcMtaDevRealmStatus, pktcMtaDevProvisioningStatus=pktcMtaDevProvisioningStatus, pktcMtaDevProvisioningCounter=pktcMtaDevProvisioningCounter, pktcMtaConformance=pktcMtaConformance, pktcMtaDevRealmUnsolicitedKeyNomTimeout=pktcMtaDevRealmUnsolicitedKeyNomTimeout, pktcMtaDevCmsUnsolicitedKeyMaxTimeout=pktcMtaDevCmsUnsolicitedKeyMaxTimeout, pktcMtaDevRealmOrgName=pktcMtaDevRealmOrgName, pktcMtaDevCmsIndex=pktcMtaDevCmsIndex, pktcMtaNotificationGroup=pktcMtaNotificationGroup, pktcMtaDevProvKerbRealmName=pktcMtaDevProvKerbRealmName, pktcMtaDevCmsSolicitedKeyTimeout=pktcMtaDevCmsSolicitedKeyTimeout, pktcMtaDevBase=pktcMtaDevBase, pktcMtaBasicCompliance=pktcMtaBasicCompliance, pktcMtaDevProvState=pktcMtaDevProvState, pktcMtaDevFQDN=pktcMtaDevFQDN, pktcMtaDevSwCurrentVers=pktcMtaDevSwCurrentVers, pktcMtaDevCmsIpsecCtrl=pktcMtaDevCmsIpsecCtrl, pktcMtaDevCmsEntry=pktcMtaDevCmsEntry, pktcMtaDevRealmIndex=pktcMtaDevRealmIndex, pktcMtaDevServerDhcp2=pktcMtaDevServerDhcp2, pktcMtaDevErrorsTooManyErrors=pktcMtaDevErrorsTooManyErrors)



#
# PySNMP MIB module NET-SNMP-EXTEND-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/NET-SNMP-EXTEND-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:34 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( nsExtensions, ) = mibBuilder.importSymbols("NET-SNMP-AGENT-MIB", "nsExtensions")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ObjectIdentity, IpAddress, MibIdentifier, Counter64, NotificationType, TimeTicks, Gauge32, Unsigned32, Counter32, Integer32, iso, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "ObjectIdentity", "IpAddress", "MibIdentifier", "Counter64", "NotificationType", "TimeTicks", "Gauge32", "Unsigned32", "Counter32", "Integer32", "iso", "ModuleIdentity")
( TextualConvention, DisplayString, RowStatus, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "RowStatus", "StorageType")
netSnmpExtendMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 8072, 1, 3, 1)).setRevisions(("2010-03-17 00:00", "2004-05-08 00:00",))
if mibBuilder.loadTexts: netSnmpExtendMIB.setLastUpdated('201003170000Z')
if mibBuilder.loadTexts: netSnmpExtendMIB.setOrganization('www.net-snmp.org')
if mibBuilder.loadTexts: netSnmpExtendMIB.setContactInfo('postal:   Wes Hardaker\n                    P.O. Box 382\n                    Davis CA  95617\n\n          email:    net-snmp-coders@lists.sourceforge.net')
if mibBuilder.loadTexts: netSnmpExtendMIB.setDescription('Defines a framework for scripted extensions for the Net-SNMP agent.')
nsExtendObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2))
nsExtendGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 3, 3))
nsExtendNumEntries = MibScalar((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendNumEntries.setDescription('The number of rows in the nsExtendConfigTable')
nsExtendConfigTable = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2), )
if mibBuilder.loadTexts: nsExtendConfigTable.setDescription('A table of scripted extensions - configuration and (basic) output.')
nsExtendConfigEntry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1), ).setIndexNames((0, "NET-SNMP-EXTEND-MIB", "nsExtendToken"))
if mibBuilder.loadTexts: nsExtendConfigEntry.setDescription('A conceptual row within the extension table.')
nsExtendToken = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 1), DisplayString())
if mibBuilder.loadTexts: nsExtendToken.setDescription('An arbitrary token to identify this extension entry')
nsExtendCommand = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 2), DisplayString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendCommand.setDescription('The full path of the command binary (or script) to run')
nsExtendArgs = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 3), DisplayString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendArgs.setDescription('Any command-line arguments for the command')
nsExtendInput = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 4), DisplayString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendInput.setDescription('The standard input for the command')
nsExtendCacheTime = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 5), Integer32().clone(5)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendCacheTime.setDescription('The length of time for which the output of\n       this command will be cached.  During this time,\n       retrieving the output-related values will not\n       reinvoke the command.\n       A value of -1 indicates that the output results\n       should not be cached at all, and retrieving each\n       individual output-related value will invoke the\n       command afresh.')
nsExtendExecType = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("exec", 1), ("shell", 2),)).clone('exec')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendExecType.setDescription('The mechanism used to invoke the command.')
nsExtendRunType = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("run-on-read", 1), ("run-on-set", 2), ("run-command", 3),)).clone('run-on-read')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendRunType.setDescription("Used to implement 'push-button' command invocation.\n       The command for a 'run-on-read' entry will be invoked\n       whenever one of the corresponding output-related\n       instances is requested (and assuming the cached value\n       is not still current).\n       The command for a 'run-on-set' entry will only be invoked\n       on receipt of a SET assignment for this object with the\n       value 'run-command'.\n       Reading an instance of this object will always return either\n       'run-on-read' or 'run-on-set'.\n      ")
nsExtendStorage = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 20), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendStorage.setDescription('The storage type for this conceptual row.')
nsExtendStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 2, 1, 21), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nsExtendStatus.setDescription("Used to create new rows in the table, in the standard manner.\n       Note that is valid for an instance to be left with the value\n       notInService(2) indefinitely - i.e. the meaning of 'abnormally\n       long' (see RFC 2579, RowStatus) for this table is infinite.")
nsExtendOutput1Table = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3), )
if mibBuilder.loadTexts: nsExtendOutput1Table.setDescription('A table of scripted extensions - configuration and (basic) output.')
nsExtendOutput1Entry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3, 1), )
nsExtendConfigEntry.registerAugmentions(("NET-SNMP-EXTEND-MIB", "nsExtendOutput1Entry"))
nsExtendOutput1Entry.setIndexNames(*nsExtendConfigEntry.getIndexNames())
if mibBuilder.loadTexts: nsExtendOutput1Entry.setDescription('A conceptual row within the extension table.')
nsExtendOutput1Line = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3, 1, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendOutput1Line.setDescription('The first line of output from the command')
nsExtendOutputFull = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendOutputFull.setDescription('The full output from the command, as a single string')
nsExtendOutNumLines = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendOutNumLines.setDescription('The number of lines of output (and hence\n       the number of rows in nsExtendOutputTable\n       relating to this particular entry).')
nsExtendResult = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 3, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendResult.setDescription('The return value of the command.')
nsExtendOutput2Table = MibTable((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 4), )
if mibBuilder.loadTexts: nsExtendOutput2Table.setDescription('A table of (line-based) output from scripted extensions.')
nsExtendOutput2Entry = MibTableRow((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 4, 1), ).setIndexNames((0, "NET-SNMP-EXTEND-MIB", "nsExtendToken"), (0, "NET-SNMP-EXTEND-MIB", "nsExtendLineIndex"))
if mibBuilder.loadTexts: nsExtendOutput2Entry.setDescription('A conceptual row within the line-based output table.')
nsExtendLineIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1024)))
if mibBuilder.loadTexts: nsExtendLineIndex.setDescription('The index of this line of output.\n       For a given nsExtendToken, this will run from\n       1 to the corresponding value of nsExtendNumLines.')
nsExtendOutLine = MibTableColumn((1, 3, 6, 1, 4, 1, 8072, 1, 3, 2, 4, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nsExtendOutLine.setDescription('A single line of output from the extension command.')
nsExtendConfigGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 1, 3, 3, 1)).setObjects(*(("NET-SNMP-EXTEND-MIB", "nsExtendCommand"), ("NET-SNMP-EXTEND-MIB", "nsExtendArgs"), ("NET-SNMP-EXTEND-MIB", "nsExtendInput"), ("NET-SNMP-EXTEND-MIB", "nsExtendCacheTime"), ("NET-SNMP-EXTEND-MIB", "nsExtendExecType"), ("NET-SNMP-EXTEND-MIB", "nsExtendRunType"), ("NET-SNMP-EXTEND-MIB", "nsExtendStorage"), ("NET-SNMP-EXTEND-MIB", "nsExtendStatus"), ("NET-SNMP-EXTEND-MIB", "nsExtendNumEntries"),))
if mibBuilder.loadTexts: nsExtendConfigGroup.setDescription('Objects relating to the configuration of extension commands.')
nsExtendOutputGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 8072, 1, 3, 3, 2)).setObjects(*(("NET-SNMP-EXTEND-MIB", "nsExtendOutNumLines"), ("NET-SNMP-EXTEND-MIB", "nsExtendResult"), ("NET-SNMP-EXTEND-MIB", "nsExtendOutLine"), ("NET-SNMP-EXTEND-MIB", "nsExtendOutput1Line"), ("NET-SNMP-EXTEND-MIB", "nsExtendOutputFull"),))
if mibBuilder.loadTexts: nsExtendOutputGroup.setDescription('Objects relating to the output of extension commands.')
mibBuilder.exportSymbols("NET-SNMP-EXTEND-MIB", nsExtendNumEntries=nsExtendNumEntries, nsExtendArgs=nsExtendArgs, nsExtendCacheTime=nsExtendCacheTime, nsExtendStatus=nsExtendStatus, nsExtendOutNumLines=nsExtendOutNumLines, nsExtendLineIndex=nsExtendLineIndex, nsExtendOutput1Line=nsExtendOutput1Line, nsExtendOutput1Table=nsExtendOutput1Table, nsExtendCommand=nsExtendCommand, nsExtendGroups=nsExtendGroups, nsExtendOutput2Table=nsExtendOutput2Table, nsExtendOutLine=nsExtendOutLine, nsExtendOutputGroup=nsExtendOutputGroup, nsExtendConfigTable=nsExtendConfigTable, nsExtendConfigGroup=nsExtendConfigGroup, nsExtendExecType=nsExtendExecType, nsExtendOutputFull=nsExtendOutputFull, nsExtendConfigEntry=nsExtendConfigEntry, nsExtendOutput2Entry=nsExtendOutput2Entry, nsExtendToken=nsExtendToken, nsExtendOutput1Entry=nsExtendOutput1Entry, nsExtendRunType=nsExtendRunType, nsExtendResult=nsExtendResult, netSnmpExtendMIB=netSnmpExtendMIB, nsExtendStorage=nsExtendStorage, nsExtendObjects=nsExtendObjects, nsExtendInput=nsExtendInput, PYSNMP_MODULE_ID=netSnmpExtendMIB)



#
# PySNMP MIB module IANA-ADDRESS-FAMILY-NUMBERS-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-ADDRESS-FAMILY-NUMBERS-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:00 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( IpAddress, Unsigned32, Counter32, iso, TimeTicks, Counter64, Bits, ModuleIdentity, Gauge32, NotificationType, ObjectIdentity, MibIdentifier, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Unsigned32", "Counter32", "iso", "TimeTicks", "Counter64", "Bits", "ModuleIdentity", "Gauge32", "NotificationType", "ObjectIdentity", "MibIdentifier", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ianaAddressFamilyNumbers = ModuleIdentity((1, 3, 6, 1, 2, 1, 72)).setRevisions(("2002-03-14 00:00", "2000-09-08 00:00", "2000-03-01 00:00", "2000-02-04 00:00", "1999-08-26 00:00",))
if mibBuilder.loadTexts: ianaAddressFamilyNumbers.setLastUpdated('200203140000Z')
if mibBuilder.loadTexts: ianaAddressFamilyNumbers.setOrganization('IANA')
if mibBuilder.loadTexts: ianaAddressFamilyNumbers.setContactInfo('Postal:    Internet Assigned Numbers Authority\n                      Internet Corporation for Assigned Names\n\t\t      and Numbers\n                      4676 Admiralty Way, Suite 330\n                      Marina del Rey, CA 90292-6601\n                      USA\n\n          Tel:    +1  310-823-9358\n          E-Mail: iana@iana.org')
if mibBuilder.loadTexts: ianaAddressFamilyNumbers.setDescription('The MIB module defines the AddressFamilyNumbers\n          textual convention.')
class AddressFamilyNumbers(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 65535,))
    namedValues = NamedValues(("other", 0), ("ipV4", 1), ("ipV6", 2), ("nsap", 3), ("hdlc", 4), ("bbn1822", 5), ("all802", 6), ("e163", 7), ("e164", 8), ("f69", 9), ("x121", 10), ("ipx", 11), ("appleTalk", 12), ("decnetIV", 13), ("banyanVines", 14), ("e164withNsap", 15), ("dns", 16), ("distinguishedName", 17), ("asNumber", 18), ("xtpOverIpv4", 19), ("xtpOverIpv6", 20), ("xtpNativeModeXTP", 21), ("fibreChannelWWPN", 22), ("fibreChannelWWNN", 23), ("gwid", 24), ("reserved", 65535),)

mibBuilder.exportSymbols("IANA-ADDRESS-FAMILY-NUMBERS-MIB", AddressFamilyNumbers=AddressFamilyNumbers, PYSNMP_MODULE_ID=ianaAddressFamilyNumbers, ianaAddressFamilyNumbers=ianaAddressFamilyNumbers)



#
# PySNMP MIB module ADSL-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ADSL-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:04:05 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Counter64, NotificationType, ObjectIdentity, transmission, iso, Integer32, MibIdentifier, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, IpAddress, ModuleIdentity, Counter32, Unsigned32, TimeTicks, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "NotificationType", "ObjectIdentity", "transmission", "iso", "Integer32", "MibIdentifier", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "IpAddress", "ModuleIdentity", "Counter32", "Unsigned32", "TimeTicks", "Bits")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
adslMIB = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94))
adsltcmib = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 94, 2)).setRevisions(("1999-08-19 00:00",))
if mibBuilder.loadTexts: adsltcmib.setLastUpdated('9908190000Z')
if mibBuilder.loadTexts: adsltcmib.setOrganization('IETF ADSL MIB Working Group')
if mibBuilder.loadTexts: adsltcmib.setContactInfo('\n       Gregory Bathrick\n       AG Communication Systems\n       A Subsidiary of Lucent Technologies\n       2500 W Utopia Rd.\n       Phoenix, AZ 85027 USA\n       Tel: +1 602-582-7679\n       Fax: +1 602-582-7697\n       E-mail: bathricg@agcs.com\n\n       Faye Ly\n       Copper Mountain Networks\n       Norcal Office\n       2470 Embarcadero Way\n       Palo Alto, CA 94303\n       Tel: +1 650-858-8500\n       Fax: +1 650-858-8085\n       E-Mail: faye@coppermountain.com\n       IETF ADSL MIB Working Group (adsl@xlist.agcs.com)\n       ')
if mibBuilder.loadTexts: adsltcmib.setDescription('The MIB module which provides a ADSL\n           Line Coding Textual Convention to be used\n           by ADSL Lines.')
class AdslLineCodingType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("other", 1), ("dmt", 2), ("cap", 3), ("qam", 4),)

class AdslPerfCurrDayCount(Gauge32, TextualConvention):
    pass

class AdslPerfPrevDayCount(Gauge32, TextualConvention):
    pass

class AdslPerfTimeElapsed(Gauge32, TextualConvention):
    pass

mibBuilder.exportSymbols("ADSL-TC-MIB", AdslLineCodingType=AdslLineCodingType, AdslPerfPrevDayCount=AdslPerfPrevDayCount, AdslPerfCurrDayCount=AdslPerfCurrDayCount, adslMIB=adslMIB, AdslPerfTimeElapsed=AdslPerfTimeElapsed, PYSNMP_MODULE_ID=adsltcmib, adsltcmib=adsltcmib)



#
# PySNMP MIB module MPLS-LDP-GENERIC-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-LDP-GENERIC-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:21:43 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( mplsLdpEntityIndex, mplsLdpEntityLdpId, ) = mibBuilder.importSymbols("MPLS-LDP-STD-MIB", "mplsLdpEntityIndex", "mplsLdpEntityLdpId")
( mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, MibIdentifier, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Unsigned32, ModuleIdentity, Gauge32, iso, Bits, TimeTicks, Integer32, IpAddress, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "MibIdentifier", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Unsigned32", "ModuleIdentity", "Gauge32", "iso", "Bits", "TimeTicks", "Integer32", "IpAddress", "ObjectIdentity")
( StorageType, RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "RowStatus", "TextualConvention", "DisplayString")
mplsLdpGenericStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 7)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsLdpGenericStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsLdpGenericStdMIB.setOrganization('Multiprotocol Label Switching (mpls)\n                      Working Group')
if mibBuilder.loadTexts: mplsLdpGenericStdMIB.setContactInfo('Joan Cucchiara (jcucchiara@mindspring.com)\n             Marconi Communications, Inc.\n    \n             Hans Sjostrand (hans@ipunplugged.com)\n             ipUnplugged\n    \n             James V. Luciani (james_luciani@mindspring.com)\n             Marconi Communications, Inc.\n    \n             Working Group Chairs:\n             George Swallow,   email: swallow@cisco.com\n             Loa Andersson,    email: loa@pi.se\n    \n             MPLS Working Group, email: mpls@uu.net\n            ')
if mibBuilder.loadTexts: mplsLdpGenericStdMIB.setDescription('Copyright (C) The Internet Society (year). The\n            initial version of this MIB module was published\n            in RFC 3815. For full legal notices see the RFC\n            itself or see:\n            http://www.ietf.org/copyrights/ianamib.html\n    \n            This MIB contains managed object definitions for\n            configuring and monitoring the Multiprotocol Label\n            Switching (MPLS), Label Distribution Protocol (LDP),\n            utilizing ethernet as the Layer 2 media.')
mplsLdpGenericObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 7, 1))
mplsLdpGenericConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 7, 2))
mplsLdpEntityGenericObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1))
mplsLdpEntityGenericLRTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1), )
if mibBuilder.loadTexts: mplsLdpEntityGenericLRTable.setDescription("The MPLS LDP Entity Generic Label Range (LR)\n            Table.\n    \n            The purpose of this table is to provide a mechanism\n            for configurating a contiguous range of generic labels,\n            or a 'label range' for LDP Entities.\n    \n            LDP Entities which use Generic Labels must have at least\n            one entry in this table.  In other words, this table\n            'extends' the mpldLdpEntityTable for Generic Labels.")
mplsLdpEntityGenericLREntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericLRMin"), (0, "MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericLRMax"))
if mibBuilder.loadTexts: mplsLdpEntityGenericLREntry.setDescription("A row in the LDP Entity Generic Label\n            Range (LR) Table.  One entry in this table contains\n            information on a single range of labels\n            represented by the configured Upper and Lower\n            Bounds pairs.  NOTE: there is NO corresponding\n            LDP message which relates to the information\n            in this table, however, this table does provide\n            a way for a user to 'reserve' a generic label\n            range.\n    \n            NOTE:  The ranges for a specific LDP Entity\n            are UNIQUE and non-overlapping.\n    \n            A row will not be created unless a unique and\n            non-overlapping range is specified.")
mplsLdpEntityGenericLRMin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,1048575)))
if mibBuilder.loadTexts: mplsLdpEntityGenericLRMin.setDescription('The minimum label configured for this range.')
mplsLdpEntityGenericLRMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,1048575)))
if mibBuilder.loadTexts: mplsLdpEntityGenericLRMax.setDescription('The maximum label configured for this range.')
mplsLdpEntityGenericLabelSpace = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("perPlatform", 1), ("perInterface", 2),)).clone('perPlatform')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityGenericLabelSpace.setDescription('This value of this object is perPlatform(1), then\n           this means that the label space type is\n           per platform.\n    \n           If this object is perInterface(2), then this\n           means that the label space type is per Interface.')
mplsLdpEntityGenericIfIndexOrZero = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 4), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityGenericIfIndexOrZero.setDescription("This value represents either the InterfaceIndex of\n           the 'ifLayer' where these Generic Label would be created,\n           or 0 (zero).  The value of zero means that the\n           InterfaceIndex is not known.\n    \n           However, if the InterfaceIndex is known,\n           then it must be represented by this value.\n    \n           If an InterfaceIndex becomes known, then the\n           network management entity (e.g., SNMP agent) responsible\n           for this object MUST change the value from 0 (zero) to the\n           value of the InterfaceIndex.")
mplsLdpEntityGenericLRStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityGenericLRStorageType.setDescription("The storage type for this conceptual row.\n            Conceptual rows having the value 'permanent(4)'\n            need not allow write-access to any columnar\n            objects in the row.")
mplsLdpEntityGenericLRRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 7, 1, 1, 1, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityGenericLRRowStatus.setDescription("The status of this conceptual row.  All writable\n             objects in this row may be modified at any time,\n             however, as described in  detail in the section\n             entitled, 'Changing Values After Session\n             Establishment', and again described in the\n             DESCRIPTION clause of the mplsLdpEntityAdminStatus object,\n             if a session has been initiated with a Peer,\n             changing objects in this table will\n             wreak havoc with the session and interrupt traffic.\n             To repeat again:  the recommended procedure is\n             to set the mplsLdpEntityAdminStatus to\n             down, thereby explicitly causing a\n             session to be torn down. Then, change objects\n             in this entry, then set the mplsLdpEntityAdminStatus\n             to enable which enables a new session to be initiated.\n    \n             There must exist at least one entry in this\n             table for every LDP Entity that has a\n             generic label configured.")
mplsLdpGenericGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 7, 2, 1))
mplsLdpGenericCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 7, 2, 2))
mplsLdpGenericModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 7, 2, 2, 1)).setObjects(*(("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpGenericGroup"),))
if mibBuilder.loadTexts: mplsLdpGenericModuleFullCompliance.setDescription('The Module is implemented with support for\n            read-create and read-write.  In other words,\n            both monitoring and configuration\n            are available when using this MODULE-COMPLIANCE.')
mplsLdpGenericModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 7, 2, 2, 2)).setObjects(*(("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpGenericGroup"),))
if mibBuilder.loadTexts: mplsLdpGenericModuleReadOnlyCompliance.setDescription('The Module is implemented with support for\n            read-only.  In other words, only monitoring\n            is available by implementing this MODULE-COMPLIANCE.')
mplsLdpGenericGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 7, 2, 1, 1)).setObjects(*(("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericLabelSpace"), ("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericIfIndexOrZero"), ("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericLRStorageType"), ("MPLS-LDP-GENERIC-STD-MIB", "mplsLdpEntityGenericLRRowStatus"),))
if mibBuilder.loadTexts: mplsLdpGenericGroup.setDescription('Objects that apply to all MPLS LDP implementations\n            using Generic Labels as the Layer 2.')
mibBuilder.exportSymbols("MPLS-LDP-GENERIC-STD-MIB", mplsLdpEntityGenericLRMax=mplsLdpEntityGenericLRMax, mplsLdpEntityGenericIfIndexOrZero=mplsLdpEntityGenericIfIndexOrZero, mplsLdpEntityGenericLRStorageType=mplsLdpEntityGenericLRStorageType, mplsLdpEntityGenericLRRowStatus=mplsLdpEntityGenericLRRowStatus, mplsLdpGenericCompliances=mplsLdpGenericCompliances, mplsLdpGenericConformance=mplsLdpGenericConformance, mplsLdpEntityGenericObjects=mplsLdpEntityGenericObjects, PYSNMP_MODULE_ID=mplsLdpGenericStdMIB, mplsLdpGenericGroups=mplsLdpGenericGroups, mplsLdpEntityGenericLREntry=mplsLdpEntityGenericLREntry, mplsLdpGenericObjects=mplsLdpGenericObjects, mplsLdpGenericModuleFullCompliance=mplsLdpGenericModuleFullCompliance, mplsLdpEntityGenericLRTable=mplsLdpEntityGenericLRTable, mplsLdpGenericGroup=mplsLdpGenericGroup, mplsLdpEntityGenericLabelSpace=mplsLdpEntityGenericLabelSpace, mplsLdpEntityGenericLRMin=mplsLdpEntityGenericLRMin, mplsLdpGenericStdMIB=mplsLdpGenericStdMIB, mplsLdpGenericModuleReadOnlyCompliance=mplsLdpGenericModuleReadOnlyCompliance)



#
# PySNMP MIB module SFLOW-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SFLOW-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:54 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( InetAddressType, InetAddress, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress")
( OwnerString, ) = mibBuilder.importSymbols("RMON-MIB", "OwnerString")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( NotificationType, Counter32, enterprises, TimeTicks, ModuleIdentity, Gauge32, Integer32, Counter64, ObjectIdentity, MibIdentifier, Unsigned32, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "Counter32", "enterprises", "TimeTicks", "ModuleIdentity", "Gauge32", "Integer32", "Counter64", "ObjectIdentity", "MibIdentifier", "Unsigned32", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "IpAddress")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
sFlowMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 14706, 1)).setRevisions(("2003-10-18 00:00", "2003-09-24 00:00", "2003-04-08 00:00", "2002-09-17 00:00", "2001-07-31 00:00", "2001-05-01 00:00",))
if mibBuilder.loadTexts: sFlowMIB.setLastUpdated('200309240000Z')
if mibBuilder.loadTexts: sFlowMIB.setOrganization('sFlow.org')
if mibBuilder.loadTexts: sFlowMIB.setContactInfo('Peter Phaal\n                sFlow.org\n                http://www.sflow.org/\n\n                Tel:  +1-415-283-3260\n                Email: peter.phaal@sflow.org')
if mibBuilder.loadTexts: sFlowMIB.setDescription('The MIB module for managing the generation and transportation\n                 of sFlow data records.')
sFlowAgent = MibIdentifier((1, 3, 6, 1, 4, 1, 14706, 1, 1))
class SFlowDataSource(ObjectIdentifier, TextualConvention):
    pass

class SFlowInstance(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,65535)

class SFlowReceiver(Integer32, TextualConvention):
    pass

sFlowVersion = MibScalar((1, 3, 6, 1, 4, 1, 14706, 1, 1, 1), SnmpAdminString().clone('1.3;;')).setMaxAccess("readonly")
if mibBuilder.loadTexts: sFlowVersion.setDescription("Uniquely identifies the version and implementation of this MIB.\n                 The version string must have the following structure:\n                    <MIB Version>;<Organization>;<Software Revision>\n                 where:\n                    <MIB Version>  must be '1.3', the version of this MIB.\n                    <Organization> the name of the organization responsible\n                                     for the agent implementation.\n                    <Revision>     the specific software build of this agent.\n\n                 As an example, the string '1.3;InMon Corp.;2.1.1' indicates\n                 that this agent implements version '1.2' of the SFLOW MIB, that\n                 it was developed by 'InMon Corp.' and that the software build\n                 is '2.1.1'.\n\n                 The MIB Version will change with each revision of the SFLOW\n                 MIB.\n\n                 Management entities must check the MIB Version and not attempt\n                 to manage agents with MIB Versions greater than that for which\n                 they were designed.\n\n                 Note: The sFlow Datagram Format has an independent version\n                       number which may change independently from <MIB Version>.\n                       <MIB Version> applies to the structure and semantics of\n                       the SFLOW MIB only.")
sFlowAgentAddressType = MibScalar((1, 3, 6, 1, 4, 1, 14706, 1, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sFlowAgentAddressType.setDescription('The address type of the address associated with this agent.\n                 Only ipv4 and ipv6 types are supported.')
sFlowAgentAddress = MibScalar((1, 3, 6, 1, 4, 1, 14706, 1, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sFlowAgentAddress.setDescription('The IP address associated with this agent. In the case of a\n                 multi-homed agent, this should be the loopback address of the\n                 agent. The sFlowAgent address must provide SNMP connectivity\n                 to the agent. The address should be an invariant that does not\n                 change as interfaces are reconfigured, enabled, disabled,\n                 added or removed. A manager should be able to use the \n                 sFlowAgentAddress as a unique key that will identify this\n                 agent over extended periods of time so that a history can\n                 be maintained.')
sFlowRcvrTable = MibTable((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4), )
if mibBuilder.loadTexts: sFlowRcvrTable.setDescription('A table of the receivers of sFlow information.')
sFlowRcvrEntry = MibTableRow((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1), ).setIndexNames((0, "SFLOW-MIB", "sFlowRcvrIndex"))
if mibBuilder.loadTexts: sFlowRcvrEntry.setDescription('Attributes of an sFlow Receiver.')
sFlowRcvrIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: sFlowRcvrIndex.setDescription('Index into sFlowReceiverTable.')
sFlowRcvrOwner = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 2), OwnerString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrOwner.setDescription('The entity making use of this sFlowRcvrTable entry. The empty\n                 string indicates that the entry is currently unclaimed.\n                 An entity wishing to claim an sFlowRcvrTable entry must ensure\n                 that the entry is unclaimed before trying to claim it.\n                 The entry is claimed by setting the owner string. The entry\n                 must be claimed before any changes can be made to other sampler\n                 objects.\n\n                 In order to avoid a race condition, the entity taking control\n                 of the sampler must set both the owner and a value for\n                 sFlowRcvrTimeout in the same SNMP set request.\n\n                 When a management entity is finished using the sampler,\n                 it should set the value of sFlowRcvrOwner back to unclaimed. \n                 The agent must restore all other entities this row to their\n                 default values when the owner is set to unclaimed. It must\n                 also free all other resources associated with this \n                 sFlowRcvrTable entry.\n\n                 This mechanism provides no enforcement and relies on the\n                 cooperation of management entities in order to ensure that\n                 competition for a receiver entry is fairly resolved.')
sFlowRcvrTimeout = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 3), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrTimeout.setDescription('The time (in seconds) remaining before the sampler is released\n                 and stops sampling. When set, the owner establishes control\n                 for the specified period. When read, the remaining time in the\n                 interval is returned.\n\n                 A management entity wanting to maintain control of the sampler\n                 is responsible for setting a new value before the old one\n                 expires.\n\n                 When the interval expires, the agent is responsible for \n                 restoring all other entities in this row to their default \n                 values. It must also free all other resources associated with\n                 this sFlowRcvrTable entry.')
sFlowRcvrMaximumDatagramSize = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 4), Integer32().clone(1400)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrMaximumDatagramSize.setDescription('The maximum number of data bytes that can be sent in a single\n                  sample datagram. The manager should set this value to avoid\n                  fragmentation of the sFlow datagrams.')
sFlowRcvrAddressType = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 5), InetAddressType().clone('ipv4')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrAddressType.setDescription('The type of sFlowRcvrCollectorAddress.')
sFlowRcvrAddress = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 6), InetAddress().clone(hexValue="00000000")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrAddress.setDescription('The IP address of the sFlow collector.\n                 If set to 0.0.0.0 not sFlow datagrams will be sent.')
sFlowRcvrPort = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 7), Integer32().clone(6343)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrPort.setDescription('The destination port for sFlow datagrams.')
sFlowRcvrDatagramVersion = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 4, 1, 8), Integer32().clone(5)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowRcvrDatagramVersion.setDescription('The version of sFlow datagrams that should be sent.\n\n                 When set to a value not support by the agent, the agent should\n                 adjust the value to the highest supported value less than the\n                 requested value, or return an SNMP bad value error if no \n                 such value exists.')
sFlowFsTable = MibTable((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5), )
if mibBuilder.loadTexts: sFlowFsTable.setDescription('A table of the flow samplers within a device.')
sFlowFsEntry = MibTableRow((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1), ).setIndexNames((0, "SFLOW-MIB", "sFlowFsDataSource"), (0, "SFLOW-MIB", "sFlowFsInstance"))
if mibBuilder.loadTexts: sFlowFsEntry.setDescription('Attributes of a flow sampler.')
sFlowFsDataSource = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1, 1), SFlowDataSource())
if mibBuilder.loadTexts: sFlowFsDataSource.setDescription('sFlowDataSource for this flow sampler.')
sFlowFsInstance = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1, 2), SFlowInstance())
if mibBuilder.loadTexts: sFlowFsInstance.setDescription('The sFlow instance for this flow sampler.')
sFlowFsReceiver = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1, 3), SFlowReceiver()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowFsReceiver.setDescription('The SFlowReceiver for this flow sampler.')
sFlowFsPacketSamplingRate = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowFsPacketSamplingRate.setDescription('The statistical sampling rate for packet sampling from this\n                 source. \n\n                 Set to N to sample 1/Nth of the packets in the monitored flows.\n                 An agent should choose its own algorithm to introduce variance\n                 into the sampling so that exactly every Nth packet is not\n                 counted. A sampling rate of 1 counts all packets. A sampling\n                 rate of 0 disables sampling.\n                 \n                 The agent is permitted to have minimum and maximum allowable\n                 values for the sampling rate. A minimum rate lets the agent\n                 designer set an upper bound on the overhead associated with\n                 sampling, and a maximum rate may be the result of hardware\n                 restrictions (such as counter size). In addition not all values\n                 between the maximum and minimum may be realizable as the \n                 sampling rate (again because of implementation considerations).\n\n                 When the sampling rate is set the agent is free to adjust the\n                 value so that it lies between the maximum and minimum values\n                 and has the closest achievable value.\n\n                 When read, the agent must return the actual sampling rate it\n                 will be using (after the adjustments previously described). The\n                 sampling algorithm must converge so that over time the number\n                 of packets sampled approaches 1/Nth of the total number of\n                 packets in the monitored flows.')
sFlowFsMaximumHeaderSize = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 5, 1, 5), Integer32().clone(128)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowFsMaximumHeaderSize.setDescription('The maximum number of bytes that should be copied from a\n                 sampled packet. The agent may have an internal maximum and\n                 minimum permissible sizes. If an attempt is made to set this \n                 value outside the permissible range then the agent should \n                 adjust the value to the closest permissible value.')
sFlowCpTable = MibTable((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6), )
if mibBuilder.loadTexts: sFlowCpTable.setDescription('A table of the counter pollers within a device.')
sFlowCpEntry = MibTableRow((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6, 1), ).setIndexNames((0, "SFLOW-MIB", "sFlowCpDataSource"), (0, "SFLOW-MIB", "sFlowCpInstance"))
if mibBuilder.loadTexts: sFlowCpEntry.setDescription('Attributes of a counter poller.')
sFlowCpDataSource = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6, 1, 1), SFlowDataSource())
if mibBuilder.loadTexts: sFlowCpDataSource.setDescription('Identifies the source of the data for the counter poller.')
sFlowCpInstance = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6, 1, 2), SFlowInstance())
if mibBuilder.loadTexts: sFlowCpInstance.setDescription('The sFlowInstance for this counter poller.')
sFlowCpReceiver = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6, 1, 3), SFlowReceiver()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowCpReceiver.setDescription('The SFlowReciever associated with this counter poller.')
sFlowCpInterval = MibTableColumn((1, 3, 6, 1, 4, 1, 14706, 1, 1, 6, 1, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sFlowCpInterval.setDescription('The maximum number of seconds between successive samples of the\n                 counters associated with this data source. A sampling interval \n                 of 0 disables counter sampling.\n\n                 The agent is permitted to have minimum and maximum allowable\n                 values for the counter polling interval. A minimum interval\n                 lets the agent designer set an upper bound on the overhead\n                 associated with polling, and a maximum interval may be the\n                 result of implementation restrictions (such as counter size).\n                 In addition not all values between the maximum and minimum may\n                 be realizable as the sampling interval (again because of\n                 implementation considerations).\n\n                 When the sampling rate is set the agent is free to adjust the\n                 value so that it lies between the maximum and minimum values\n                 and has the closest achievable value.\n\n                 When read, the agent must return the actual sampling interval\n                 it will be using (after the adjustments previously described).\n                 The sampling algorithm must converge so that over time the\n                 number of packets sampled approaches 1/Nth of the total number\n                 of packets in the monitored flows.')
sFlowMIBConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 14706, 1, 2))
sFlowMIBGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 14706, 1, 2, 1))
sFlowMIBCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 14706, 1, 2, 2))
sFlowCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 14706, 1, 2, 2, 1)).setObjects(*(("SFLOW-MIB", "sFlowAgentGroup"),))
if mibBuilder.loadTexts: sFlowCompliance.setDescription('Compliance statements for the sFlow Agent.')
sFlowAgentGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 14706, 1, 2, 1, 1)).setObjects(*(("SFLOW-MIB", "sFlowVersion"), ("SFLOW-MIB", "sFlowAgentAddressType"), ("SFLOW-MIB", "sFlowAgentAddress"), ("SFLOW-MIB", "sFlowRcvrOwner"), ("SFLOW-MIB", "sFlowRcvrTimeout"), ("SFLOW-MIB", "sFlowRcvrMaximumDatagramSize"), ("SFLOW-MIB", "sFlowRcvrAddressType"), ("SFLOW-MIB", "sFlowRcvrAddress"), ("SFLOW-MIB", "sFlowRcvrPort"), ("SFLOW-MIB", "sFlowRcvrDatagramVersion"), ("SFLOW-MIB", "sFlowFsReceiver"), ("SFLOW-MIB", "sFlowFsPacketSamplingRate"), ("SFLOW-MIB", "sFlowFsMaximumHeaderSize"), ("SFLOW-MIB", "sFlowCpReceiver"), ("SFLOW-MIB", "sFlowCpInterval"),))
if mibBuilder.loadTexts: sFlowAgentGroup.setDescription('A collection of objects for managing the generation and\n                  transportation of sFlow data records.')
mibBuilder.exportSymbols("SFLOW-MIB", sFlowAgent=sFlowAgent, sFlowVersion=sFlowVersion, sFlowMIB=sFlowMIB, SFlowReceiver=SFlowReceiver, sFlowRcvrPort=sFlowRcvrPort, sFlowCpTable=sFlowCpTable, sFlowMIBConformance=sFlowMIBConformance, sFlowRcvrEntry=sFlowRcvrEntry, sFlowFsMaximumHeaderSize=sFlowFsMaximumHeaderSize, sFlowCompliance=sFlowCompliance, sFlowRcvrAddressType=sFlowRcvrAddressType, sFlowAgentAddressType=sFlowAgentAddressType, sFlowRcvrIndex=sFlowRcvrIndex, sFlowRcvrDatagramVersion=sFlowRcvrDatagramVersion, sFlowAgentAddress=sFlowAgentAddress, sFlowCpDataSource=sFlowCpDataSource, SFlowDataSource=SFlowDataSource, sFlowFsTable=sFlowFsTable, sFlowRcvrAddress=sFlowRcvrAddress, sFlowCpReceiver=sFlowCpReceiver, sFlowMIBCompliances=sFlowMIBCompliances, SFlowInstance=SFlowInstance, sFlowRcvrTable=sFlowRcvrTable, sFlowCpEntry=sFlowCpEntry, sFlowCpInterval=sFlowCpInterval, sFlowFsInstance=sFlowFsInstance, sFlowFsPacketSamplingRate=sFlowFsPacketSamplingRate, sFlowAgentGroup=sFlowAgentGroup, sFlowRcvrOwner=sFlowRcvrOwner, sFlowRcvrMaximumDatagramSize=sFlowRcvrMaximumDatagramSize, sFlowFsEntry=sFlowFsEntry, sFlowFsReceiver=sFlowFsReceiver, sFlowFsDataSource=sFlowFsDataSource, PYSNMP_MODULE_ID=sFlowMIB, sFlowMIBGroups=sFlowMIBGroups, sFlowCpInstance=sFlowCpInstance, sFlowRcvrTimeout=sFlowRcvrTimeout)
